#! /usr/bin/env python3

"""
TODO: g2engine_grpc.py
"""

# pylint: disable=E1101

from types import TracebackType
from typing import Any, Dict, Iterable, Tuple, Type, Union

import grpc
from senzing_abstract import G2EngineAbstract, G2EngineFlags

from .g2helpers import as_str, new_exception
from .pb2_grpc import g2engine_pb2, g2engine_pb2_grpc

# Metadata

__all__ = ["G2EngineGrpc"]
__version__ = "0.0.1"  # See https://www.python.org/dev/peps/pep-0396/
__date__ = "2023-11-27"
__updated__ = "2023-12-16"

SENZING_PRODUCT_ID = "5053"  # See https://github.com/Senzing/knowledge-base/blob/main/lists/senzing-component-ids.md

# -----------------------------------------------------------------------------
# G2EngineGrpc class
# -----------------------------------------------------------------------------


class G2EngineGrpc(G2EngineAbstract):  # type: ignore
    """
    G2 engine module access library over gRPC.
    """

    # -------------------------------------------------------------------------
    # Python dunder/magic methods
    # -------------------------------------------------------------------------

    def __init__(
        self,
        grpc_channel: grpc.Channel,
    ) -> None:
        """
        Constructor

        For return value of -> None, see https://peps.python.org/pep-0484/#the-meaning-of-annotations
        """

        self.channel = grpc_channel
        self.stub = g2engine_pb2_grpc.G2EngineStub(self.channel)
        self.noop = ""

    def __enter__(
        self,
    ) -> (
        Any
    ):  # TODO: Replace "Any" with "Self" once python 3.11 is lowest supported python version.
        """Context Manager method."""
        return self

    def __exit__(
        self,
        exc_type: Union[Type[BaseException], None],
        exc_val: Union[BaseException, None],
        exc_tb: Union[TracebackType, None],
    ) -> None:
        """Context Manager method."""

    # -------------------------------------------------------------------------
    # Development methods - to be removed after initial development
    # -------------------------------------------------------------------------

    def fake_g2engine(self, *args: Any, **kwargs: Any) -> None:
        """TODO: Remove once SDK methods have been implemented."""
        if len(args) + len(kwargs) > 2000:
            print(self.noop)

    # -------------------------------------------------------------------------
    # G2Engine methods
    # -------------------------------------------------------------------------

    def add_record(
        self,
        data_source_code: str,
        record_id: str,
        json_data: Union[str, Dict[Any, Any]],
        # TODO: load_id is no longer used, being removed from V4 C api?
        load_id: str = "",
        flags: int = 0,  # pylint: disable=W0613
        **kwargs: Any,
    ) -> None:
        try:
            request = g2engine_pb2.AddRecordRequest(  # type: ignore[unused-ignore]
                dataSourceCode=data_source_code,
                recordID=record_id,
                jsonData=as_str(json_data),
                loadID=load_id,
            )
            self.stub.AddRecord(request)
        except Exception as err:
            raise new_exception(err) from err

    def add_record_with_info(
        self,
        data_source_code: str,
        record_id: str,
        json_data: Union[str, Dict[Any, Any]],
        # TODO: load_id is no longer used, being removed from V4 C api?
        load_id: str = "",
        flags: int = 0,
        **kwargs: Any,
    ) -> str:
        try:
            request = g2engine_pb2.AddRecordWithInfoRequest(  # type: ignore[unused-ignore]
                dataSourceCode=data_source_code,
                recordID=record_id,
                jsonData=as_str(json_data),
                loadID=load_id,
            )
            response = self.stub.AddRecordWithInfo(request)
            return str(response.result)
        except Exception as err:
            raise new_exception(err) from err

    def close_export(self, response_handle: int, **kwargs: Any) -> None:
        self.fake_g2engine(response_handle)

    def count_redo_records(self, **kwargs: Any) -> int:
        try:
            request = g2engine_pb2.CountRedoRecordsRequest()  # type: ignore[unused-ignore]
            response = self.stub.CountRedoRecords(request)
            return int(response.result)
        except Exception as err:
            raise new_exception(err) from err

    def delete_record(
        self,
        data_source_code: str,
        record_id: str,
        # TODO: load_id is no longer used, being removed from V4 C api?
        load_id: str = "",
        **kwargs: Any,
    ) -> None:
        try:
            request = g2engine_pb2.DeleteRecordRequest(  # type: ignore[unused-ignore]
                dataSourceCode=data_source_code,
                recordID=record_id,
                loadID=load_id,
            )
            self.stub.DeleteRecord(request)
        except Exception as err:
            raise new_exception(err) from err

    def delete_record_with_info(
        self,
        data_source_code: str,
        record_id: str,
        # TODO: load_id is no longer used, being removed from V4 C api?
        load_id: str = "",
        flags: int = 0,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(data_source_code, record_id, load_id, flags)
        return "string"

    def destroy(self, **kwargs: Any) -> None:
        """Null function"""

    def export_config(self, **kwargs: Any) -> str:
        self.fake_g2engine()
        return "string"

    def export_config_and_config_id(self, **kwargs: Any) -> Tuple[str, int]:
        self.fake_g2engine()
        return "string", 0

    def export_csv_entity_report(
        self,
        csv_column_list: str,
        flags: int = G2EngineFlags.G2_EXPORT_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> int:
        self.fake_g2engine(csv_column_list, flags)
        return 0

    def export_csv_entity_report_iterator(
        self,
        flags: int = G2EngineFlags.G2_EXPORT_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> Iterable[str]:
        if len(kwargs) > 0:
            pass  # TODO: To disable pylint W0613
        try:
            request = g2engine_pb2.StreamExportCSVEntityReportRequest(  # type: ignore[unused-ignore]
                flags=flags
            )
            for item in self.stub.StreamExportCSVEntityReport(request):
                if item.result:
                    yield item.result
        except Exception as err:
            raise new_exception(err) from err

    def export_json_entity_report(
        self, flags: int = G2EngineFlags.G2_EXPORT_DEFAULT_FLAGS, **kwargs: Any
    ) -> int:
        self.fake_g2engine(flags)
        return 0

    def export_json_entity_report_iterator(
        self,
        flags: int = G2EngineFlags.G2_EXPORT_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> Iterable[str]:
        if len(kwargs) > 0:
            pass  # TODO: To disable pylint W0613
        try:
            request = g2engine_pb2.StreamExportJSONEntityReportRequest(  # type: ignore[unused-ignore]
                flags=flags
            )
            for item in self.stub.StreamExportJSONEntityReport(request):
                if item.result:
                    yield item.result
        except Exception as err:
            raise new_exception(err) from err

    def fetch_next(self, response_handle: int, **kwargs: Any) -> str:
        self.fake_g2engine(response_handle)
        return "string"

    def find_interesting_entities_by_entity_id(
        self, entity_id: int, flags: int = 0, **kwargs: Any
    ) -> str:
        self.fake_g2engine(entity_id, flags)
        return "string"

    def find_interesting_entities_by_record_id(
        self,
        data_source_code: str,
        record_id: str,
        flags: int = 0,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(data_source_code, record_id, flags)
        return "string"

    def find_network_by_entity_id_v2(
        self,
        entity_list: Union[str, Dict[Any, Any]],
        max_degree: int,
        build_out_degree: int,
        max_entities: int,
        flags: int = G2EngineFlags.G2_FIND_PATH_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(
            entity_list, max_degree, build_out_degree, max_entities, flags
        )
        return "string"

    def find_network_by_entity_id(
        self,
        entity_list: Union[str, Dict[Any, Any]],
        max_degree: int,
        build_out_degree: int,
        max_entities: int,
        flags: int = G2EngineFlags.G2_FIND_PATH_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(entity_list, max_degree, build_out_degree, max_entities)
        return "string"

    def find_network_by_record_id_v2(
        self,
        record_list: Union[str, Dict[Any, Any]],
        max_degree: int,
        build_out_degree: int,
        max_entities: int,
        flags: int = G2EngineFlags.G2_FIND_PATH_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(
            record_list, max_degree, build_out_degree, max_entities, flags
        )
        return "string"

    def find_network_by_record_id(
        self,
        record_list: Union[str, Dict[Any, Any]],
        max_degree: int,
        build_out_degree: int,
        max_entities: int,
        flags: int = G2EngineFlags.G2_FIND_PATH_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(record_list, max_degree, build_out_degree, max_entities)
        return "string"

    def find_path_by_entity_id_v2(
        self,
        entity_id_1: int,
        entity_id_2: int,
        max_degree: int,
        flags: int = G2EngineFlags.G2_FIND_PATH_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(entity_id_1, entity_id_2, max_degree, flags)
        return "string"

    def find_path_by_entity_id(
        self,
        entity_id_1: int,
        entity_id_2: int,
        max_degree: int,
        flags: int = G2EngineFlags.G2_FIND_PATH_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(entity_id_1, entity_id_2, max_degree)
        return "string"

    def find_path_by_record_id_v2(
        self,
        data_source_code_1: str,
        record_id_1: str,
        data_source_code_2: str,
        record_id_2: str,
        max_degree: int,
        flags: int = G2EngineFlags.G2_FIND_PATH_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(
            data_source_code_1,
            record_id_1,
            data_source_code_2,
            record_id_2,
            max_degree,
            flags,
        )
        return "string"

    def find_path_by_record_id(
        self,
        data_source_code_1: str,
        record_id_1: str,
        data_source_code_2: str,
        record_id_2: str,
        max_degree: int,
        flags: int = G2EngineFlags.G2_FIND_PATH_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(
            data_source_code_1, record_id_1, data_source_code_2, record_id_2, max_degree
        )
        return "string"

    def find_path_excluding_by_entity_id_v2(
        self,
        entity_id_1: int,
        entity_id_2: int,
        max_degree: int,
        excluded_entities: Union[str, Dict[Any, Any]],
        flags: int = G2EngineFlags.G2_FIND_PATH_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(
            entity_id_1, entity_id_2, max_degree, excluded_entities, flags
        )
        return "string"

    def find_path_excluding_by_entity_id(
        self,
        entity_id_1: int,
        entity_id_2: int,
        max_degree: int,
        excluded_entities: Union[str, Dict[Any, Any]],
        flags: int = G2EngineFlags.G2_FIND_PATH_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(entity_id_1, entity_id_2, max_degree, excluded_entities)
        return "string"

    def find_path_excluding_by_record_id_v2(
        self,
        data_source_code_1: str,
        record_id_1: str,
        data_source_code_2: str,
        record_id_2: str,
        max_degree: int,
        excluded_records: Union[str, Dict[Any, Any]],
        flags: int = G2EngineFlags.G2_FIND_PATH_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(
            data_source_code_1,
            record_id_1,
            data_source_code_2,
            record_id_2,
            max_degree,
            excluded_records,
            flags,
        )
        return "string"

    def find_path_excluding_by_record_id(
        self,
        data_source_code_1: str,
        record_id_1: str,
        data_source_code_2: str,
        record_id_2: str,
        max_degree: int,
        excluded_records: Union[str, Dict[Any, Any]],
        flags: int = G2EngineFlags.G2_FIND_PATH_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(
            data_source_code_1,
            record_id_1,
            data_source_code_2,
            record_id_2,
            max_degree,
            excluded_records,
        )
        return "string"

    def find_path_including_source_by_entity_id_v2(
        self,
        entity_id_1: int,
        entity_id_2: int,
        max_degree: int,
        excluded_entities: Union[str, Dict[Any, Any]],
        required_dsrcs: Union[str, Dict[Any, Any]],
        flags: int = G2EngineFlags.G2_FIND_PATH_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(
            entity_id_1,
            entity_id_2,
            max_degree,
            excluded_entities,
            required_dsrcs,
            flags,
        )
        return "string"

    def find_path_including_source_by_entity_id(
        self,
        entity_id_1: int,
        entity_id_2: int,
        max_degree: int,
        excluded_entities: Union[str, Dict[Any, Any]],
        required_dsrcs: Union[str, Dict[Any, Any]],
        flags: int = G2EngineFlags.G2_FIND_PATH_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(
            entity_id_1, entity_id_2, max_degree, excluded_entities, required_dsrcs
        )
        return "string"

    def find_path_including_source_by_record_id_v2(
        self,
        data_source_code_1: str,
        record_id_1: str,
        data_source_code_2: str,
        record_id_2: str,
        max_degree: int,
        excluded_records: Union[str, Dict[Any, Any]],
        required_dsrcs: Union[str, Dict[Any, Any]],
        flags: int = G2EngineFlags.G2_FIND_PATH_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(
            data_source_code_1,
            record_id_1,
            data_source_code_2,
            record_id_2,
            max_degree,
            excluded_records,
            required_dsrcs,
            flags,
        )
        return "string"

    def find_path_including_source_by_record_id(
        self,
        data_source_code_1: str,
        record_id_1: str,
        data_source_code_2: str,
        record_id_2: str,
        max_degree: int,
        excluded_records: Union[str, Dict[Any, Any]],
        required_dsrcs: Union[str, Dict[Any, Any]],
        flags: int = G2EngineFlags.G2_FIND_PATH_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(
            data_source_code_1,
            record_id_1,
            data_source_code_2,
            record_id_2,
            max_degree,
            excluded_records,
            required_dsrcs,
        )
        return "string"

    def get_active_config_id(self, **kwargs: Any) -> int:
        self.fake_g2engine()
        return 0

    def get_entity_by_entity_id_v2(
        self,
        entity_id: int,
        flags: int = G2EngineFlags.G2_ENTITY_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(entity_id, flags)
        return "string"

    def get_entity_by_entity_id(
        self,
        entity_id: int,
        flags: int = G2EngineFlags.G2_ENTITY_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(entity_id)
        return "string"

    def get_entity_by_record_id_v2(
        self,
        data_source_code: str,
        record_id: str,
        flags: int = G2EngineFlags.G2_ENTITY_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(data_source_code, record_id, flags)
        return "string"

    def get_entity_by_record_id(
        self,
        data_source_code: str,
        record_id: str,
        flags: int = G2EngineFlags.G2_ENTITY_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(data_source_code, record_id)
        return "string"

    def get_record_v2(
        self,
        data_source_code: str,
        record_id: str,
        flags: int = G2EngineFlags.G2_RECORD_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(data_source_code, record_id, flags)
        return "string"

    def get_record(
        self,
        data_source_code: str,
        record_id: str,
        flags: int = G2EngineFlags.G2_RECORD_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(data_source_code, record_id)
        return "string"

    def get_redo_record(self, **kwargs: Any) -> str:
        self.fake_g2engine()
        return "string"

    def get_repository_last_modified_time(self, **kwargs: Any) -> int:
        self.fake_g2engine()
        return 0

    def get_virtual_entity_by_record_id_v2(
        self,
        record_list: Union[str, Dict[Any, Any]],
        flags: int = G2EngineFlags.G2_HOW_ENTITY_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(record_list, flags)
        return "string"

    def get_virtual_entity_by_record_id(
        self,
        record_list: Union[str, Dict[Any, Any]],
        flags: int = G2EngineFlags.G2_HOW_ENTITY_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(record_list)
        return "string"

    def how_entity_by_entity_id_v2(
        self,
        entity_id: int,
        flags: int = G2EngineFlags.G2_HOW_ENTITY_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(entity_id, flags)
        return "string"

    def how_entity_by_entity_id(
        self,
        entity_id: int,
        flags: int = G2EngineFlags.G2_HOW_ENTITY_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(entity_id)
        return "string"

    def init(
        self,
        module_name: str,
        ini_params: Union[str, Dict[Any, Any]],
        verbose_logging: int = 0,
        **kwargs: Any,
    ) -> None:
        """Null function"""

    def init_with_config_id(
        self,
        module_name: str,
        ini_params: Union[str, Dict[Any, Any]],
        init_config_id: int,
        verbose_logging: int = 0,
        **kwargs: Any,
    ) -> None:
        """Null function"""

    def prime_engine(self, **kwargs: Any) -> None:
        """Null function"""

    def process(self, record: Union[str, Dict[Any, Any]], **kwargs: Any) -> None:
        self.fake_g2engine(record)

    def process_with_info(
        self, record: Union[str, Dict[Any, Any]], flags: int, **kwargs: Any
    ) -> str:
        self.fake_g2engine(record, flags)
        return "string"

    def purge_repository(self, **kwargs: Any) -> None:
        self.fake_g2engine()

    def reevaluate_entity(self, entity_id: int, flags: int = 0, **kwargs: Any) -> None:
        self.fake_g2engine(entity_id, flags)

    def reevaluate_entity_with_info(
        self, entity_id: int, flags: int = 0, **kwargs: Any
    ) -> str:
        self.fake_g2engine(entity_id, flags)
        return "string"

    def reevaluate_record(
        self,
        data_source_code: str,
        record_id: str,
        flags: int = 0,
        **kwargs: Any,
    ) -> None:
        self.fake_g2engine(data_source_code, record_id, flags)

    def reevaluate_record_with_info(
        self,
        data_source_code: str,
        record_id: str,
        flags: int = 0,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(data_source_code, record_id, flags)
        return "string"

    def reinit(self, init_config_id: int, **kwargs: Any) -> None:
        try:
            request = g2engine_pb2.ReinitRequest(  # type: ignore[unused-ignore]
                initConfigID=init_config_id,
            )
            self.stub.Reinit(request)
        except Exception as err:
            raise new_exception(err) from err

    def replace_record(
        self,
        data_source_code: str,
        record_id: str,
        json_data: Union[str, Dict[Any, Any]],
        # TODO: load_id is no longer used, being removed from V4 C api?
        load_id: str = "",
        **kwargs: Any,
    ) -> None:
        self.fake_g2engine(data_source_code, record_id, json_data, load_id)

    def replace_record_with_info(
        self,
        data_source_code: str,
        record_id: str,
        json_data: Union[str, Dict[Any, Any]],
        # TODO: load_id is no longer used, being removed from V4 C api?
        load_id: str = "",
        flags: int = 0,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(data_source_code, record_id, json_data, load_id, flags)
        return "string"

    def search_by_attributes_v2(
        self,
        json_data: Union[str, Dict[Any, Any]],
        flags: int = G2EngineFlags.G2_SEARCH_BY_ATTRIBUTES_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(json_data, flags, flags)
        return "string"

    def search_by_attributes_v3(
        self,
        json_data: Union[str, Dict[Any, Any]],
        search_profile: str,
        flags: int = G2EngineFlags.G2_SEARCH_BY_ATTRIBUTES_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(json_data, search_profile, flags)
        return "string"

    def search_by_attributes(
        self,
        json_data: Union[str, Dict[Any, Any]],
        flags: int = G2EngineFlags.G2_SEARCH_BY_ATTRIBUTES_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(json_data)
        return "string"

    def stats(self, **kwargs: Any) -> str:
        self.fake_g2engine()
        return "string"

    def why_entities_v2(
        self,
        entity_id_1: int,
        entity_id_2: int,
        flags: int = G2EngineFlags.G2_WHY_ENTITY_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(entity_id_1, entity_id_2, flags)
        return "string"

    def why_entities(
        self,
        entity_id_1: int,
        entity_id_2: int,
        flags: int = G2EngineFlags.G2_WHY_ENTITY_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(entity_id_1, entity_id_2)
        return "string"

    def why_entity_by_entity_id_v2(
        self,
        entity_id: int,
        flags: int = G2EngineFlags.G2_WHY_ENTITY_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(entity_id, flags)
        return "string"

    def why_entity_by_entity_id(
        self,
        entity_id: int,
        flags: int = G2EngineFlags.G2_WHY_ENTITY_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(entity_id)
        return "string"

    def why_entity_by_record_id_v2(
        self,
        data_source_code: str,
        record_id: str,
        flags: int = G2EngineFlags.G2_WHY_ENTITY_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(data_source_code, record_id, flags)
        return "string"

    def why_entity_by_record_id(
        self,
        data_source_code: str,
        record_id: str,
        flags: int = G2EngineFlags.G2_WHY_ENTITY_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(data_source_code, record_id)
        return "string"

    def why_record_in_entity(
        self,
        data_source_code: str,
        record_id: str,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(data_source_code, record_id)
        return "string"

    def why_record_in_entity_v2(
        self,
        data_source_code: str,
        record_id: str,
        flags: int,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(data_source_code, record_id, flags)
        return "string"

    def why_records_v2(
        self,
        data_source_code_1: str,
        record_id_1: str,
        data_source_code_2: str,
        record_id_2: str,
        flags: int = G2EngineFlags.G2_WHY_ENTITY_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(
            data_source_code_1, record_id_1, data_source_code_2, record_id_2, flags
        )
        return "string"

    def why_records(
        self,
        data_source_code_1: str,
        record_id_1: str,
        data_source_code_2: str,
        record_id_2: str,
        flags: int = G2EngineFlags.G2_WHY_ENTITY_DEFAULT_FLAGS,
        **kwargs: Any,
    ) -> str:
        self.fake_g2engine(
            data_source_code_1, record_id_1, data_source_code_2, record_id_2
        )
        return "string"



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""

# pylint: disable=R0205,R0902,R0903,R0913,E1101


import grpc

from . import g2engine_pb2 as g2engine__pb2


class G2EngineStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.AddRecord = channel.unary_unary(
            "/g2engine.G2Engine/AddRecord",
            request_serializer=g2engine__pb2.AddRecordRequest.SerializeToString,
            response_deserializer=g2engine__pb2.AddRecordResponse.FromString,
        )
        self.AddRecordWithInfo = channel.unary_unary(
            "/g2engine.G2Engine/AddRecordWithInfo",
            request_serializer=g2engine__pb2.AddRecordWithInfoRequest.SerializeToString,
            response_deserializer=g2engine__pb2.AddRecordWithInfoResponse.FromString,
        )
        self.CloseExport = channel.unary_unary(
            "/g2engine.G2Engine/CloseExport",
            request_serializer=g2engine__pb2.CloseExportRequest.SerializeToString,
            response_deserializer=g2engine__pb2.CloseExportResponse.FromString,
        )
        self.CountRedoRecords = channel.unary_unary(
            "/g2engine.G2Engine/CountRedoRecords",
            request_serializer=g2engine__pb2.CountRedoRecordsRequest.SerializeToString,
            response_deserializer=g2engine__pb2.CountRedoRecordsResponse.FromString,
        )
        self.DeleteRecord = channel.unary_unary(
            "/g2engine.G2Engine/DeleteRecord",
            request_serializer=g2engine__pb2.DeleteRecordRequest.SerializeToString,
            response_deserializer=g2engine__pb2.DeleteRecordResponse.FromString,
        )
        self.DeleteRecordWithInfo = channel.unary_unary(
            "/g2engine.G2Engine/DeleteRecordWithInfo",
            request_serializer=g2engine__pb2.DeleteRecordWithInfoRequest.SerializeToString,
            response_deserializer=g2engine__pb2.DeleteRecordWithInfoResponse.FromString,
        )
        self.Destroy = channel.unary_unary(
            "/g2engine.G2Engine/Destroy",
            request_serializer=g2engine__pb2.DestroyRequest.SerializeToString,
            response_deserializer=g2engine__pb2.DestroyResponse.FromString,
        )
        self.ExportConfig = channel.unary_unary(
            "/g2engine.G2Engine/ExportConfig",
            request_serializer=g2engine__pb2.ExportConfigRequest.SerializeToString,
            response_deserializer=g2engine__pb2.ExportConfigResponse.FromString,
        )
        self.ExportConfigAndConfigID = channel.unary_unary(
            "/g2engine.G2Engine/ExportConfigAndConfigID",
            request_serializer=g2engine__pb2.ExportConfigAndConfigIDRequest.SerializeToString,
            response_deserializer=g2engine__pb2.ExportConfigAndConfigIDResponse.FromString,
        )
        self.ExportCSVEntityReport = channel.unary_unary(
            "/g2engine.G2Engine/ExportCSVEntityReport",
            request_serializer=g2engine__pb2.ExportCSVEntityReportRequest.SerializeToString,
            response_deserializer=g2engine__pb2.ExportCSVEntityReportResponse.FromString,
        )
        self.ExportJSONEntityReport = channel.unary_unary(
            "/g2engine.G2Engine/ExportJSONEntityReport",
            request_serializer=g2engine__pb2.ExportJSONEntityReportRequest.SerializeToString,
            response_deserializer=g2engine__pb2.ExportJSONEntityReportResponse.FromString,
        )
        self.FetchNext = channel.unary_unary(
            "/g2engine.G2Engine/FetchNext",
            request_serializer=g2engine__pb2.FetchNextRequest.SerializeToString,
            response_deserializer=g2engine__pb2.FetchNextResponse.FromString,
        )
        self.FindInterestingEntitiesByEntityID = channel.unary_unary(
            "/g2engine.G2Engine/FindInterestingEntitiesByEntityID",
            request_serializer=g2engine__pb2.FindInterestingEntitiesByEntityIDRequest.SerializeToString,
            response_deserializer=g2engine__pb2.FindInterestingEntitiesByEntityIDResponse.FromString,
        )
        self.FindInterestingEntitiesByRecordID = channel.unary_unary(
            "/g2engine.G2Engine/FindInterestingEntitiesByRecordID",
            request_serializer=g2engine__pb2.FindInterestingEntitiesByRecordIDRequest.SerializeToString,
            response_deserializer=g2engine__pb2.FindInterestingEntitiesByRecordIDResponse.FromString,
        )
        self.FindNetworkByEntityID = channel.unary_unary(
            "/g2engine.G2Engine/FindNetworkByEntityID",
            request_serializer=g2engine__pb2.FindNetworkByEntityIDRequest.SerializeToString,
            response_deserializer=g2engine__pb2.FindNetworkByEntityIDResponse.FromString,
        )
        self.FindNetworkByEntityID_V2 = channel.unary_unary(
            "/g2engine.G2Engine/FindNetworkByEntityID_V2",
            request_serializer=g2engine__pb2.FindNetworkByEntityID_V2Request.SerializeToString,
            response_deserializer=g2engine__pb2.FindNetworkByEntityID_V2Response.FromString,
        )
        self.FindNetworkByRecordID = channel.unary_unary(
            "/g2engine.G2Engine/FindNetworkByRecordID",
            request_serializer=g2engine__pb2.FindNetworkByRecordIDRequest.SerializeToString,
            response_deserializer=g2engine__pb2.FindNetworkByRecordIDResponse.FromString,
        )
        self.FindNetworkByRecordID_V2 = channel.unary_unary(
            "/g2engine.G2Engine/FindNetworkByRecordID_V2",
            request_serializer=g2engine__pb2.FindNetworkByRecordID_V2Request.SerializeToString,
            response_deserializer=g2engine__pb2.FindNetworkByRecordID_V2Response.FromString,
        )
        self.FindPathByEntityID = channel.unary_unary(
            "/g2engine.G2Engine/FindPathByEntityID",
            request_serializer=g2engine__pb2.FindPathByEntityIDRequest.SerializeToString,
            response_deserializer=g2engine__pb2.FindPathByEntityIDResponse.FromString,
        )
        self.FindPathByEntityID_V2 = channel.unary_unary(
            "/g2engine.G2Engine/FindPathByEntityID_V2",
            request_serializer=g2engine__pb2.FindPathByEntityID_V2Request.SerializeToString,
            response_deserializer=g2engine__pb2.FindPathByEntityID_V2Response.FromString,
        )
        self.FindPathByRecordID = channel.unary_unary(
            "/g2engine.G2Engine/FindPathByRecordID",
            request_serializer=g2engine__pb2.FindPathByRecordIDRequest.SerializeToString,
            response_deserializer=g2engine__pb2.FindPathByRecordIDResponse.FromString,
        )
        self.FindPathByRecordID_V2 = channel.unary_unary(
            "/g2engine.G2Engine/FindPathByRecordID_V2",
            request_serializer=g2engine__pb2.FindPathByRecordID_V2Request.SerializeToString,
            response_deserializer=g2engine__pb2.FindPathByRecordID_V2Response.FromString,
        )
        self.FindPathExcludingByEntityID = channel.unary_unary(
            "/g2engine.G2Engine/FindPathExcludingByEntityID",
            request_serializer=g2engine__pb2.FindPathExcludingByEntityIDRequest.SerializeToString,
            response_deserializer=g2engine__pb2.FindPathExcludingByEntityIDResponse.FromString,
        )
        self.FindPathExcludingByEntityID_V2 = channel.unary_unary(
            "/g2engine.G2Engine/FindPathExcludingByEntityID_V2",
            request_serializer=g2engine__pb2.FindPathExcludingByEntityID_V2Request.SerializeToString,
            response_deserializer=g2engine__pb2.FindPathExcludingByEntityID_V2Response.FromString,
        )
        self.FindPathExcludingByRecordID = channel.unary_unary(
            "/g2engine.G2Engine/FindPathExcludingByRecordID",
            request_serializer=g2engine__pb2.FindPathExcludingByRecordIDRequest.SerializeToString,
            response_deserializer=g2engine__pb2.FindPathExcludingByRecordIDResponse.FromString,
        )
        self.FindPathExcludingByRecordID_V2 = channel.unary_unary(
            "/g2engine.G2Engine/FindPathExcludingByRecordID_V2",
            request_serializer=g2engine__pb2.FindPathExcludingByRecordID_V2Request.SerializeToString,
            response_deserializer=g2engine__pb2.FindPathExcludingByRecordID_V2Response.FromString,
        )
        self.FindPathIncludingSourceByEntityID = channel.unary_unary(
            "/g2engine.G2Engine/FindPathIncludingSourceByEntityID",
            request_serializer=g2engine__pb2.FindPathIncludingSourceByEntityIDRequest.SerializeToString,
            response_deserializer=g2engine__pb2.FindPathIncludingSourceByEntityIDResponse.FromString,
        )
        self.FindPathIncludingSourceByEntityID_V2 = channel.unary_unary(
            "/g2engine.G2Engine/FindPathIncludingSourceByEntityID_V2",
            request_serializer=g2engine__pb2.FindPathIncludingSourceByEntityID_V2Request.SerializeToString,
            response_deserializer=g2engine__pb2.FindPathIncludingSourceByEntityID_V2Response.FromString,
        )
        self.FindPathIncludingSourceByRecordID = channel.unary_unary(
            "/g2engine.G2Engine/FindPathIncludingSourceByRecordID",
            request_serializer=g2engine__pb2.FindPathIncludingSourceByRecordIDRequest.SerializeToString,
            response_deserializer=g2engine__pb2.FindPathIncludingSourceByRecordIDResponse.FromString,
        )
        self.FindPathIncludingSourceByRecordID_V2 = channel.unary_unary(
            "/g2engine.G2Engine/FindPathIncludingSourceByRecordID_V2",
            request_serializer=g2engine__pb2.FindPathIncludingSourceByRecordID_V2Request.SerializeToString,
            response_deserializer=g2engine__pb2.FindPathIncludingSourceByRecordID_V2Response.FromString,
        )
        self.GetActiveConfigID = channel.unary_unary(
            "/g2engine.G2Engine/GetActiveConfigID",
            request_serializer=g2engine__pb2.GetActiveConfigIDRequest.SerializeToString,
            response_deserializer=g2engine__pb2.GetActiveConfigIDResponse.FromString,
        )
        self.GetEntityByEntityID = channel.unary_unary(
            "/g2engine.G2Engine/GetEntityByEntityID",
            request_serializer=g2engine__pb2.GetEntityByEntityIDRequest.SerializeToString,
            response_deserializer=g2engine__pb2.GetEntityByEntityIDResponse.FromString,
        )
        self.GetEntityByEntityID_V2 = channel.unary_unary(
            "/g2engine.G2Engine/GetEntityByEntityID_V2",
            request_serializer=g2engine__pb2.GetEntityByEntityID_V2Request.SerializeToString,
            response_deserializer=g2engine__pb2.GetEntityByEntityID_V2Response.FromString,
        )
        self.GetEntityByRecordID = channel.unary_unary(
            "/g2engine.G2Engine/GetEntityByRecordID",
            request_serializer=g2engine__pb2.GetEntityByRecordIDRequest.SerializeToString,
            response_deserializer=g2engine__pb2.GetEntityByRecordIDResponse.FromString,
        )
        self.GetEntityByRecordID_V2 = channel.unary_unary(
            "/g2engine.G2Engine/GetEntityByRecordID_V2",
            request_serializer=g2engine__pb2.GetEntityByRecordID_V2Request.SerializeToString,
            response_deserializer=g2engine__pb2.GetEntityByRecordID_V2Response.FromString,
        )
        self.GetRecord = channel.unary_unary(
            "/g2engine.G2Engine/GetRecord",
            request_serializer=g2engine__pb2.GetRecordRequest.SerializeToString,
            response_deserializer=g2engine__pb2.GetRecordResponse.FromString,
        )
        self.GetRecord_V2 = channel.unary_unary(
            "/g2engine.G2Engine/GetRecord_V2",
            request_serializer=g2engine__pb2.GetRecord_V2Request.SerializeToString,
            response_deserializer=g2engine__pb2.GetRecord_V2Response.FromString,
        )
        self.GetRedoRecord = channel.unary_unary(
            "/g2engine.G2Engine/GetRedoRecord",
            request_serializer=g2engine__pb2.GetRedoRecordRequest.SerializeToString,
            response_deserializer=g2engine__pb2.GetRedoRecordResponse.FromString,
        )
        self.GetRepositoryLastModifiedTime = channel.unary_unary(
            "/g2engine.G2Engine/GetRepositoryLastModifiedTime",
            request_serializer=g2engine__pb2.GetRepositoryLastModifiedTimeRequest.SerializeToString,
            response_deserializer=g2engine__pb2.GetRepositoryLastModifiedTimeResponse.FromString,
        )
        self.GetVirtualEntityByRecordID = channel.unary_unary(
            "/g2engine.G2Engine/GetVirtualEntityByRecordID",
            request_serializer=g2engine__pb2.GetVirtualEntityByRecordIDRequest.SerializeToString,
            response_deserializer=g2engine__pb2.GetVirtualEntityByRecordIDResponse.FromString,
        )
        self.GetVirtualEntityByRecordID_V2 = channel.unary_unary(
            "/g2engine.G2Engine/GetVirtualEntityByRecordID_V2",
            request_serializer=g2engine__pb2.GetVirtualEntityByRecordID_V2Request.SerializeToString,
            response_deserializer=g2engine__pb2.GetVirtualEntityByRecordID_V2Response.FromString,
        )
        self.HowEntityByEntityID = channel.unary_unary(
            "/g2engine.G2Engine/HowEntityByEntityID",
            request_serializer=g2engine__pb2.HowEntityByEntityIDRequest.SerializeToString,
            response_deserializer=g2engine__pb2.HowEntityByEntityIDResponse.FromString,
        )
        self.HowEntityByEntityID_V2 = channel.unary_unary(
            "/g2engine.G2Engine/HowEntityByEntityID_V2",
            request_serializer=g2engine__pb2.HowEntityByEntityID_V2Request.SerializeToString,
            response_deserializer=g2engine__pb2.HowEntityByEntityID_V2Response.FromString,
        )
        self.Init = channel.unary_unary(
            "/g2engine.G2Engine/Init",
            request_serializer=g2engine__pb2.InitRequest.SerializeToString,
            response_deserializer=g2engine__pb2.InitResponse.FromString,
        )
        self.InitWithConfigID = channel.unary_unary(
            "/g2engine.G2Engine/InitWithConfigID",
            request_serializer=g2engine__pb2.InitWithConfigIDRequest.SerializeToString,
            response_deserializer=g2engine__pb2.InitWithConfigIDResponse.FromString,
        )
        self.PrimeEngine = channel.unary_unary(
            "/g2engine.G2Engine/PrimeEngine",
            request_serializer=g2engine__pb2.PrimeEngineRequest.SerializeToString,
            response_deserializer=g2engine__pb2.PrimeEngineResponse.FromString,
        )
        self.Process = channel.unary_unary(
            "/g2engine.G2Engine/Process",
            request_serializer=g2engine__pb2.ProcessRequest.SerializeToString,
            response_deserializer=g2engine__pb2.ProcessResponse.FromString,
        )
        self.ProcessWithInfo = channel.unary_unary(
            "/g2engine.G2Engine/ProcessWithInfo",
            request_serializer=g2engine__pb2.ProcessWithInfoRequest.SerializeToString,
            response_deserializer=g2engine__pb2.ProcessWithInfoResponse.FromString,
        )
        self.PurgeRepository = channel.unary_unary(
            "/g2engine.G2Engine/PurgeRepository",
            request_serializer=g2engine__pb2.PurgeRepositoryRequest.SerializeToString,
            response_deserializer=g2engine__pb2.PurgeRepositoryResponse.FromString,
        )
        self.ReevaluateEntity = channel.unary_unary(
            "/g2engine.G2Engine/ReevaluateEntity",
            request_serializer=g2engine__pb2.ReevaluateEntityRequest.SerializeToString,
            response_deserializer=g2engine__pb2.ReevaluateEntityResponse.FromString,
        )
        self.ReevaluateEntityWithInfo = channel.unary_unary(
            "/g2engine.G2Engine/ReevaluateEntityWithInfo",
            request_serializer=g2engine__pb2.ReevaluateEntityWithInfoRequest.SerializeToString,
            response_deserializer=g2engine__pb2.ReevaluateEntityWithInfoResponse.FromString,
        )
        self.ReevaluateRecord = channel.unary_unary(
            "/g2engine.G2Engine/ReevaluateRecord",
            request_serializer=g2engine__pb2.ReevaluateRecordRequest.SerializeToString,
            response_deserializer=g2engine__pb2.ReevaluateRecordResponse.FromString,
        )
        self.ReevaluateRecordWithInfo = channel.unary_unary(
            "/g2engine.G2Engine/ReevaluateRecordWithInfo",
            request_serializer=g2engine__pb2.ReevaluateRecordWithInfoRequest.SerializeToString,
            response_deserializer=g2engine__pb2.ReevaluateRecordWithInfoResponse.FromString,
        )
        self.Reinit = channel.unary_unary(
            "/g2engine.G2Engine/Reinit",
            request_serializer=g2engine__pb2.ReinitRequest.SerializeToString,
            response_deserializer=g2engine__pb2.ReinitResponse.FromString,
        )
        self.ReplaceRecord = channel.unary_unary(
            "/g2engine.G2Engine/ReplaceRecord",
            request_serializer=g2engine__pb2.ReplaceRecordRequest.SerializeToString,
            response_deserializer=g2engine__pb2.ReplaceRecordResponse.FromString,
        )
        self.ReplaceRecordWithInfo = channel.unary_unary(
            "/g2engine.G2Engine/ReplaceRecordWithInfo",
            request_serializer=g2engine__pb2.ReplaceRecordWithInfoRequest.SerializeToString,
            response_deserializer=g2engine__pb2.ReplaceRecordWithInfoResponse.FromString,
        )
        self.SearchByAttributes = channel.unary_unary(
            "/g2engine.G2Engine/SearchByAttributes",
            request_serializer=g2engine__pb2.SearchByAttributesRequest.SerializeToString,
            response_deserializer=g2engine__pb2.SearchByAttributesResponse.FromString,
        )
        self.SearchByAttributes_V2 = channel.unary_unary(
            "/g2engine.G2Engine/SearchByAttributes_V2",
            request_serializer=g2engine__pb2.SearchByAttributes_V2Request.SerializeToString,
            response_deserializer=g2engine__pb2.SearchByAttributes_V2Response.FromString,
        )
        self.Stats = channel.unary_unary(
            "/g2engine.G2Engine/Stats",
            request_serializer=g2engine__pb2.StatsRequest.SerializeToString,
            response_deserializer=g2engine__pb2.StatsResponse.FromString,
        )
        self.StreamExportCSVEntityReport = channel.unary_stream(
            "/g2engine.G2Engine/StreamExportCSVEntityReport",
            request_serializer=g2engine__pb2.StreamExportCSVEntityReportRequest.SerializeToString,
            response_deserializer=g2engine__pb2.StreamExportCSVEntityReportResponse.FromString,
        )
        self.StreamExportJSONEntityReport = channel.unary_stream(
            "/g2engine.G2Engine/StreamExportJSONEntityReport",
            request_serializer=g2engine__pb2.StreamExportJSONEntityReportRequest.SerializeToString,
            response_deserializer=g2engine__pb2.StreamExportJSONEntityReportResponse.FromString,
        )
        self.WhyEntities = channel.unary_unary(
            "/g2engine.G2Engine/WhyEntities",
            request_serializer=g2engine__pb2.WhyEntitiesRequest.SerializeToString,
            response_deserializer=g2engine__pb2.WhyEntitiesResponse.FromString,
        )
        self.WhyEntities_V2 = channel.unary_unary(
            "/g2engine.G2Engine/WhyEntities_V2",
            request_serializer=g2engine__pb2.WhyEntities_V2Request.SerializeToString,
            response_deserializer=g2engine__pb2.WhyEntities_V2Response.FromString,
        )
        self.WhyEntityByEntityID = channel.unary_unary(
            "/g2engine.G2Engine/WhyEntityByEntityID",
            request_serializer=g2engine__pb2.WhyEntityByEntityIDRequest.SerializeToString,
            response_deserializer=g2engine__pb2.WhyEntityByEntityIDResponse.FromString,
        )
        self.WhyEntityByEntityID_V2 = channel.unary_unary(
            "/g2engine.G2Engine/WhyEntityByEntityID_V2",
            request_serializer=g2engine__pb2.WhyEntityByEntityID_V2Request.SerializeToString,
            response_deserializer=g2engine__pb2.WhyEntityByEntityID_V2Response.FromString,
        )
        self.WhyEntityByRecordID = channel.unary_unary(
            "/g2engine.G2Engine/WhyEntityByRecordID",
            request_serializer=g2engine__pb2.WhyEntityByRecordIDRequest.SerializeToString,
            response_deserializer=g2engine__pb2.WhyEntityByRecordIDResponse.FromString,
        )
        self.WhyEntityByRecordID_V2 = channel.unary_unary(
            "/g2engine.G2Engine/WhyEntityByRecordID_V2",
            request_serializer=g2engine__pb2.WhyEntityByRecordID_V2Request.SerializeToString,
            response_deserializer=g2engine__pb2.WhyEntityByRecordID_V2Response.FromString,
        )
        self.WhyRecords = channel.unary_unary(
            "/g2engine.G2Engine/WhyRecords",
            request_serializer=g2engine__pb2.WhyRecordsRequest.SerializeToString,
            response_deserializer=g2engine__pb2.WhyRecordsResponse.FromString,
        )
        self.WhyRecords_V2 = channel.unary_unary(
            "/g2engine.G2Engine/WhyRecords_V2",
            request_serializer=g2engine__pb2.WhyRecords_V2Request.SerializeToString,
            response_deserializer=g2engine__pb2.WhyRecords_V2Response.FromString,
        )


class G2EngineServicer(object):
    """Missing associated documentation comment in .proto file."""

    def AddRecord(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def AddRecordWithInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CloseExport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CountRedoRecords(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeleteRecord(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeleteRecordWithInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Destroy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ExportConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ExportConfigAndConfigID(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ExportCSVEntityReport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ExportJSONEntityReport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def FetchNext(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def FindInterestingEntitiesByEntityID(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def FindInterestingEntitiesByRecordID(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def FindNetworkByEntityID(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def FindNetworkByEntityID_V2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def FindNetworkByRecordID(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def FindNetworkByRecordID_V2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def FindPathByEntityID(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def FindPathByEntityID_V2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def FindPathByRecordID(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def FindPathByRecordID_V2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def FindPathExcludingByEntityID(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def FindPathExcludingByEntityID_V2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def FindPathExcludingByRecordID(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def FindPathExcludingByRecordID_V2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def FindPathIncludingSourceByEntityID(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def FindPathIncludingSourceByEntityID_V2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def FindPathIncludingSourceByRecordID(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def FindPathIncludingSourceByRecordID_V2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetActiveConfigID(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetEntityByEntityID(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetEntityByEntityID_V2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetEntityByRecordID(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetEntityByRecordID_V2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetRecord(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetRecord_V2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetRedoRecord(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetRepositoryLastModifiedTime(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetVirtualEntityByRecordID(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetVirtualEntityByRecordID_V2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def HowEntityByEntityID(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def HowEntityByEntityID_V2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Init(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def InitWithConfigID(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def PrimeEngine(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Process(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ProcessWithInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def PurgeRepository(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ReevaluateEntity(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ReevaluateEntityWithInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ReevaluateRecord(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ReevaluateRecordWithInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Reinit(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ReplaceRecord(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ReplaceRecordWithInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def SearchByAttributes(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def SearchByAttributes_V2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Stats(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def StreamExportCSVEntityReport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def StreamExportJSONEntityReport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def WhyEntities(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def WhyEntities_V2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def WhyEntityByEntityID(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def WhyEntityByEntityID_V2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def WhyEntityByRecordID(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def WhyEntityByRecordID_V2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def WhyRecords(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def WhyRecords_V2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_G2EngineServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "AddRecord": grpc.unary_unary_rpc_method_handler(
            servicer.AddRecord,
            request_deserializer=g2engine__pb2.AddRecordRequest.FromString,
            response_serializer=g2engine__pb2.AddRecordResponse.SerializeToString,
        ),
        "AddRecordWithInfo": grpc.unary_unary_rpc_method_handler(
            servicer.AddRecordWithInfo,
            request_deserializer=g2engine__pb2.AddRecordWithInfoRequest.FromString,
            response_serializer=g2engine__pb2.AddRecordWithInfoResponse.SerializeToString,
        ),
        "CloseExport": grpc.unary_unary_rpc_method_handler(
            servicer.CloseExport,
            request_deserializer=g2engine__pb2.CloseExportRequest.FromString,
            response_serializer=g2engine__pb2.CloseExportResponse.SerializeToString,
        ),
        "CountRedoRecords": grpc.unary_unary_rpc_method_handler(
            servicer.CountRedoRecords,
            request_deserializer=g2engine__pb2.CountRedoRecordsRequest.FromString,
            response_serializer=g2engine__pb2.CountRedoRecordsResponse.SerializeToString,
        ),
        "DeleteRecord": grpc.unary_unary_rpc_method_handler(
            servicer.DeleteRecord,
            request_deserializer=g2engine__pb2.DeleteRecordRequest.FromString,
            response_serializer=g2engine__pb2.DeleteRecordResponse.SerializeToString,
        ),
        "DeleteRecordWithInfo": grpc.unary_unary_rpc_method_handler(
            servicer.DeleteRecordWithInfo,
            request_deserializer=g2engine__pb2.DeleteRecordWithInfoRequest.FromString,
            response_serializer=g2engine__pb2.DeleteRecordWithInfoResponse.SerializeToString,
        ),
        "Destroy": grpc.unary_unary_rpc_method_handler(
            servicer.Destroy,
            request_deserializer=g2engine__pb2.DestroyRequest.FromString,
            response_serializer=g2engine__pb2.DestroyResponse.SerializeToString,
        ),
        "ExportConfig": grpc.unary_unary_rpc_method_handler(
            servicer.ExportConfig,
            request_deserializer=g2engine__pb2.ExportConfigRequest.FromString,
            response_serializer=g2engine__pb2.ExportConfigResponse.SerializeToString,
        ),
        "ExportConfigAndConfigID": grpc.unary_unary_rpc_method_handler(
            servicer.ExportConfigAndConfigID,
            request_deserializer=g2engine__pb2.ExportConfigAndConfigIDRequest.FromString,
            response_serializer=g2engine__pb2.ExportConfigAndConfigIDResponse.SerializeToString,
        ),
        "ExportCSVEntityReport": grpc.unary_unary_rpc_method_handler(
            servicer.ExportCSVEntityReport,
            request_deserializer=g2engine__pb2.ExportCSVEntityReportRequest.FromString,
            response_serializer=g2engine__pb2.ExportCSVEntityReportResponse.SerializeToString,
        ),
        "ExportJSONEntityReport": grpc.unary_unary_rpc_method_handler(
            servicer.ExportJSONEntityReport,
            request_deserializer=g2engine__pb2.ExportJSONEntityReportRequest.FromString,
            response_serializer=g2engine__pb2.ExportJSONEntityReportResponse.SerializeToString,
        ),
        "FetchNext": grpc.unary_unary_rpc_method_handler(
            servicer.FetchNext,
            request_deserializer=g2engine__pb2.FetchNextRequest.FromString,
            response_serializer=g2engine__pb2.FetchNextResponse.SerializeToString,
        ),
        "FindInterestingEntitiesByEntityID": grpc.unary_unary_rpc_method_handler(
            servicer.FindInterestingEntitiesByEntityID,
            request_deserializer=g2engine__pb2.FindInterestingEntitiesByEntityIDRequest.FromString,
            response_serializer=g2engine__pb2.FindInterestingEntitiesByEntityIDResponse.SerializeToString,
        ),
        "FindInterestingEntitiesByRecordID": grpc.unary_unary_rpc_method_handler(
            servicer.FindInterestingEntitiesByRecordID,
            request_deserializer=g2engine__pb2.FindInterestingEntitiesByRecordIDRequest.FromString,
            response_serializer=g2engine__pb2.FindInterestingEntitiesByRecordIDResponse.SerializeToString,
        ),
        "FindNetworkByEntityID": grpc.unary_unary_rpc_method_handler(
            servicer.FindNetworkByEntityID,
            request_deserializer=g2engine__pb2.FindNetworkByEntityIDRequest.FromString,
            response_serializer=g2engine__pb2.FindNetworkByEntityIDResponse.SerializeToString,
        ),
        "FindNetworkByEntityID_V2": grpc.unary_unary_rpc_method_handler(
            servicer.FindNetworkByEntityID_V2,
            request_deserializer=g2engine__pb2.FindNetworkByEntityID_V2Request.FromString,
            response_serializer=g2engine__pb2.FindNetworkByEntityID_V2Response.SerializeToString,
        ),
        "FindNetworkByRecordID": grpc.unary_unary_rpc_method_handler(
            servicer.FindNetworkByRecordID,
            request_deserializer=g2engine__pb2.FindNetworkByRecordIDRequest.FromString,
            response_serializer=g2engine__pb2.FindNetworkByRecordIDResponse.SerializeToString,
        ),
        "FindNetworkByRecordID_V2": grpc.unary_unary_rpc_method_handler(
            servicer.FindNetworkByRecordID_V2,
            request_deserializer=g2engine__pb2.FindNetworkByRecordID_V2Request.FromString,
            response_serializer=g2engine__pb2.FindNetworkByRecordID_V2Response.SerializeToString,
        ),
        "FindPathByEntityID": grpc.unary_unary_rpc_method_handler(
            servicer.FindPathByEntityID,
            request_deserializer=g2engine__pb2.FindPathByEntityIDRequest.FromString,
            response_serializer=g2engine__pb2.FindPathByEntityIDResponse.SerializeToString,
        ),
        "FindPathByEntityID_V2": grpc.unary_unary_rpc_method_handler(
            servicer.FindPathByEntityID_V2,
            request_deserializer=g2engine__pb2.FindPathByEntityID_V2Request.FromString,
            response_serializer=g2engine__pb2.FindPathByEntityID_V2Response.SerializeToString,
        ),
        "FindPathByRecordID": grpc.unary_unary_rpc_method_handler(
            servicer.FindPathByRecordID,
            request_deserializer=g2engine__pb2.FindPathByRecordIDRequest.FromString,
            response_serializer=g2engine__pb2.FindPathByRecordIDResponse.SerializeToString,
        ),
        "FindPathByRecordID_V2": grpc.unary_unary_rpc_method_handler(
            servicer.FindPathByRecordID_V2,
            request_deserializer=g2engine__pb2.FindPathByRecordID_V2Request.FromString,
            response_serializer=g2engine__pb2.FindPathByRecordID_V2Response.SerializeToString,
        ),
        "FindPathExcludingByEntityID": grpc.unary_unary_rpc_method_handler(
            servicer.FindPathExcludingByEntityID,
            request_deserializer=g2engine__pb2.FindPathExcludingByEntityIDRequest.FromString,
            response_serializer=g2engine__pb2.FindPathExcludingByEntityIDResponse.SerializeToString,
        ),
        "FindPathExcludingByEntityID_V2": grpc.unary_unary_rpc_method_handler(
            servicer.FindPathExcludingByEntityID_V2,
            request_deserializer=g2engine__pb2.FindPathExcludingByEntityID_V2Request.FromString,
            response_serializer=g2engine__pb2.FindPathExcludingByEntityID_V2Response.SerializeToString,
        ),
        "FindPathExcludingByRecordID": grpc.unary_unary_rpc_method_handler(
            servicer.FindPathExcludingByRecordID,
            request_deserializer=g2engine__pb2.FindPathExcludingByRecordIDRequest.FromString,
            response_serializer=g2engine__pb2.FindPathExcludingByRecordIDResponse.SerializeToString,
        ),
        "FindPathExcludingByRecordID_V2": grpc.unary_unary_rpc_method_handler(
            servicer.FindPathExcludingByRecordID_V2,
            request_deserializer=g2engine__pb2.FindPathExcludingByRecordID_V2Request.FromString,
            response_serializer=g2engine__pb2.FindPathExcludingByRecordID_V2Response.SerializeToString,
        ),
        "FindPathIncludingSourceByEntityID": grpc.unary_unary_rpc_method_handler(
            servicer.FindPathIncludingSourceByEntityID,
            request_deserializer=g2engine__pb2.FindPathIncludingSourceByEntityIDRequest.FromString,
            response_serializer=g2engine__pb2.FindPathIncludingSourceByEntityIDResponse.SerializeToString,
        ),
        "FindPathIncludingSourceByEntityID_V2": grpc.unary_unary_rpc_method_handler(
            servicer.FindPathIncludingSourceByEntityID_V2,
            request_deserializer=g2engine__pb2.FindPathIncludingSourceByEntityID_V2Request.FromString,
            response_serializer=g2engine__pb2.FindPathIncludingSourceByEntityID_V2Response.SerializeToString,
        ),
        "FindPathIncludingSourceByRecordID": grpc.unary_unary_rpc_method_handler(
            servicer.FindPathIncludingSourceByRecordID,
            request_deserializer=g2engine__pb2.FindPathIncludingSourceByRecordIDRequest.FromString,
            response_serializer=g2engine__pb2.FindPathIncludingSourceByRecordIDResponse.SerializeToString,
        ),
        "FindPathIncludingSourceByRecordID_V2": grpc.unary_unary_rpc_method_handler(
            servicer.FindPathIncludingSourceByRecordID_V2,
            request_deserializer=g2engine__pb2.FindPathIncludingSourceByRecordID_V2Request.FromString,
            response_serializer=g2engine__pb2.FindPathIncludingSourceByRecordID_V2Response.SerializeToString,
        ),
        "GetActiveConfigID": grpc.unary_unary_rpc_method_handler(
            servicer.GetActiveConfigID,
            request_deserializer=g2engine__pb2.GetActiveConfigIDRequest.FromString,
            response_serializer=g2engine__pb2.GetActiveConfigIDResponse.SerializeToString,
        ),
        "GetEntityByEntityID": grpc.unary_unary_rpc_method_handler(
            servicer.GetEntityByEntityID,
            request_deserializer=g2engine__pb2.GetEntityByEntityIDRequest.FromString,
            response_serializer=g2engine__pb2.GetEntityByEntityIDResponse.SerializeToString,
        ),
        "GetEntityByEntityID_V2": grpc.unary_unary_rpc_method_handler(
            servicer.GetEntityByEntityID_V2,
            request_deserializer=g2engine__pb2.GetEntityByEntityID_V2Request.FromString,
            response_serializer=g2engine__pb2.GetEntityByEntityID_V2Response.SerializeToString,
        ),
        "GetEntityByRecordID": grpc.unary_unary_rpc_method_handler(
            servicer.GetEntityByRecordID,
            request_deserializer=g2engine__pb2.GetEntityByRecordIDRequest.FromString,
            response_serializer=g2engine__pb2.GetEntityByRecordIDResponse.SerializeToString,
        ),
        "GetEntityByRecordID_V2": grpc.unary_unary_rpc_method_handler(
            servicer.GetEntityByRecordID_V2,
            request_deserializer=g2engine__pb2.GetEntityByRecordID_V2Request.FromString,
            response_serializer=g2engine__pb2.GetEntityByRecordID_V2Response.SerializeToString,
        ),
        "GetRecord": grpc.unary_unary_rpc_method_handler(
            servicer.GetRecord,
            request_deserializer=g2engine__pb2.GetRecordRequest.FromString,
            response_serializer=g2engine__pb2.GetRecordResponse.SerializeToString,
        ),
        "GetRecord_V2": grpc.unary_unary_rpc_method_handler(
            servicer.GetRecord_V2,
            request_deserializer=g2engine__pb2.GetRecord_V2Request.FromString,
            response_serializer=g2engine__pb2.GetRecord_V2Response.SerializeToString,
        ),
        "GetRedoRecord": grpc.unary_unary_rpc_method_handler(
            servicer.GetRedoRecord,
            request_deserializer=g2engine__pb2.GetRedoRecordRequest.FromString,
            response_serializer=g2engine__pb2.GetRedoRecordResponse.SerializeToString,
        ),
        "GetRepositoryLastModifiedTime": grpc.unary_unary_rpc_method_handler(
            servicer.GetRepositoryLastModifiedTime,
            request_deserializer=g2engine__pb2.GetRepositoryLastModifiedTimeRequest.FromString,
            response_serializer=g2engine__pb2.GetRepositoryLastModifiedTimeResponse.SerializeToString,
        ),
        "GetVirtualEntityByRecordID": grpc.unary_unary_rpc_method_handler(
            servicer.GetVirtualEntityByRecordID,
            request_deserializer=g2engine__pb2.GetVirtualEntityByRecordIDRequest.FromString,
            response_serializer=g2engine__pb2.GetVirtualEntityByRecordIDResponse.SerializeToString,
        ),
        "GetVirtualEntityByRecordID_V2": grpc.unary_unary_rpc_method_handler(
            servicer.GetVirtualEntityByRecordID_V2,
            request_deserializer=g2engine__pb2.GetVirtualEntityByRecordID_V2Request.FromString,
            response_serializer=g2engine__pb2.GetVirtualEntityByRecordID_V2Response.SerializeToString,
        ),
        "HowEntityByEntityID": grpc.unary_unary_rpc_method_handler(
            servicer.HowEntityByEntityID,
            request_deserializer=g2engine__pb2.HowEntityByEntityIDRequest.FromString,
            response_serializer=g2engine__pb2.HowEntityByEntityIDResponse.SerializeToString,
        ),
        "HowEntityByEntityID_V2": grpc.unary_unary_rpc_method_handler(
            servicer.HowEntityByEntityID_V2,
            request_deserializer=g2engine__pb2.HowEntityByEntityID_V2Request.FromString,
            response_serializer=g2engine__pb2.HowEntityByEntityID_V2Response.SerializeToString,
        ),
        "Init": grpc.unary_unary_rpc_method_handler(
            servicer.Init,
            request_deserializer=g2engine__pb2.InitRequest.FromString,
            response_serializer=g2engine__pb2.InitResponse.SerializeToString,
        ),
        "InitWithConfigID": grpc.unary_unary_rpc_method_handler(
            servicer.InitWithConfigID,
            request_deserializer=g2engine__pb2.InitWithConfigIDRequest.FromString,
            response_serializer=g2engine__pb2.InitWithConfigIDResponse.SerializeToString,
        ),
        "PrimeEngine": grpc.unary_unary_rpc_method_handler(
            servicer.PrimeEngine,
            request_deserializer=g2engine__pb2.PrimeEngineRequest.FromString,
            response_serializer=g2engine__pb2.PrimeEngineResponse.SerializeToString,
        ),
        "Process": grpc.unary_unary_rpc_method_handler(
            servicer.Process,
            request_deserializer=g2engine__pb2.ProcessRequest.FromString,
            response_serializer=g2engine__pb2.ProcessResponse.SerializeToString,
        ),
        "ProcessWithInfo": grpc.unary_unary_rpc_method_handler(
            servicer.ProcessWithInfo,
            request_deserializer=g2engine__pb2.ProcessWithInfoRequest.FromString,
            response_serializer=g2engine__pb2.ProcessWithInfoResponse.SerializeToString,
        ),
        "PurgeRepository": grpc.unary_unary_rpc_method_handler(
            servicer.PurgeRepository,
            request_deserializer=g2engine__pb2.PurgeRepositoryRequest.FromString,
            response_serializer=g2engine__pb2.PurgeRepositoryResponse.SerializeToString,
        ),
        "ReevaluateEntity": grpc.unary_unary_rpc_method_handler(
            servicer.ReevaluateEntity,
            request_deserializer=g2engine__pb2.ReevaluateEntityRequest.FromString,
            response_serializer=g2engine__pb2.ReevaluateEntityResponse.SerializeToString,
        ),
        "ReevaluateEntityWithInfo": grpc.unary_unary_rpc_method_handler(
            servicer.ReevaluateEntityWithInfo,
            request_deserializer=g2engine__pb2.ReevaluateEntityWithInfoRequest.FromString,
            response_serializer=g2engine__pb2.ReevaluateEntityWithInfoResponse.SerializeToString,
        ),
        "ReevaluateRecord": grpc.unary_unary_rpc_method_handler(
            servicer.ReevaluateRecord,
            request_deserializer=g2engine__pb2.ReevaluateRecordRequest.FromString,
            response_serializer=g2engine__pb2.ReevaluateRecordResponse.SerializeToString,
        ),
        "ReevaluateRecordWithInfo": grpc.unary_unary_rpc_method_handler(
            servicer.ReevaluateRecordWithInfo,
            request_deserializer=g2engine__pb2.ReevaluateRecordWithInfoRequest.FromString,
            response_serializer=g2engine__pb2.ReevaluateRecordWithInfoResponse.SerializeToString,
        ),
        "Reinit": grpc.unary_unary_rpc_method_handler(
            servicer.Reinit,
            request_deserializer=g2engine__pb2.ReinitRequest.FromString,
            response_serializer=g2engine__pb2.ReinitResponse.SerializeToString,
        ),
        "ReplaceRecord": grpc.unary_unary_rpc_method_handler(
            servicer.ReplaceRecord,
            request_deserializer=g2engine__pb2.ReplaceRecordRequest.FromString,
            response_serializer=g2engine__pb2.ReplaceRecordResponse.SerializeToString,
        ),
        "ReplaceRecordWithInfo": grpc.unary_unary_rpc_method_handler(
            servicer.ReplaceRecordWithInfo,
            request_deserializer=g2engine__pb2.ReplaceRecordWithInfoRequest.FromString,
            response_serializer=g2engine__pb2.ReplaceRecordWithInfoResponse.SerializeToString,
        ),
        "SearchByAttributes": grpc.unary_unary_rpc_method_handler(
            servicer.SearchByAttributes,
            request_deserializer=g2engine__pb2.SearchByAttributesRequest.FromString,
            response_serializer=g2engine__pb2.SearchByAttributesResponse.SerializeToString,
        ),
        "SearchByAttributes_V2": grpc.unary_unary_rpc_method_handler(
            servicer.SearchByAttributes_V2,
            request_deserializer=g2engine__pb2.SearchByAttributes_V2Request.FromString,
            response_serializer=g2engine__pb2.SearchByAttributes_V2Response.SerializeToString,
        ),
        "Stats": grpc.unary_unary_rpc_method_handler(
            servicer.Stats,
            request_deserializer=g2engine__pb2.StatsRequest.FromString,
            response_serializer=g2engine__pb2.StatsResponse.SerializeToString,
        ),
        "StreamExportCSVEntityReport": grpc.unary_stream_rpc_method_handler(
            servicer.StreamExportCSVEntityReport,
            request_deserializer=g2engine__pb2.StreamExportCSVEntityReportRequest.FromString,
            response_serializer=g2engine__pb2.StreamExportCSVEntityReportResponse.SerializeToString,
        ),
        "StreamExportJSONEntityReport": grpc.unary_stream_rpc_method_handler(
            servicer.StreamExportJSONEntityReport,
            request_deserializer=g2engine__pb2.StreamExportJSONEntityReportRequest.FromString,
            response_serializer=g2engine__pb2.StreamExportJSONEntityReportResponse.SerializeToString,
        ),
        "WhyEntities": grpc.unary_unary_rpc_method_handler(
            servicer.WhyEntities,
            request_deserializer=g2engine__pb2.WhyEntitiesRequest.FromString,
            response_serializer=g2engine__pb2.WhyEntitiesResponse.SerializeToString,
        ),
        "WhyEntities_V2": grpc.unary_unary_rpc_method_handler(
            servicer.WhyEntities_V2,
            request_deserializer=g2engine__pb2.WhyEntities_V2Request.FromString,
            response_serializer=g2engine__pb2.WhyEntities_V2Response.SerializeToString,
        ),
        "WhyEntityByEntityID": grpc.unary_unary_rpc_method_handler(
            servicer.WhyEntityByEntityID,
            request_deserializer=g2engine__pb2.WhyEntityByEntityIDRequest.FromString,
            response_serializer=g2engine__pb2.WhyEntityByEntityIDResponse.SerializeToString,
        ),
        "WhyEntityByEntityID_V2": grpc.unary_unary_rpc_method_handler(
            servicer.WhyEntityByEntityID_V2,
            request_deserializer=g2engine__pb2.WhyEntityByEntityID_V2Request.FromString,
            response_serializer=g2engine__pb2.WhyEntityByEntityID_V2Response.SerializeToString,
        ),
        "WhyEntityByRecordID": grpc.unary_unary_rpc_method_handler(
            servicer.WhyEntityByRecordID,
            request_deserializer=g2engine__pb2.WhyEntityByRecordIDRequest.FromString,
            response_serializer=g2engine__pb2.WhyEntityByRecordIDResponse.SerializeToString,
        ),
        "WhyEntityByRecordID_V2": grpc.unary_unary_rpc_method_handler(
            servicer.WhyEntityByRecordID_V2,
            request_deserializer=g2engine__pb2.WhyEntityByRecordID_V2Request.FromString,
            response_serializer=g2engine__pb2.WhyEntityByRecordID_V2Response.SerializeToString,
        ),
        "WhyRecords": grpc.unary_unary_rpc_method_handler(
            servicer.WhyRecords,
            request_deserializer=g2engine__pb2.WhyRecordsRequest.FromString,
            response_serializer=g2engine__pb2.WhyRecordsResponse.SerializeToString,
        ),
        "WhyRecords_V2": grpc.unary_unary_rpc_method_handler(
            servicer.WhyRecords_V2,
            request_deserializer=g2engine__pb2.WhyRecords_V2Request.FromString,
            response_serializer=g2engine__pb2.WhyRecords_V2Response.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "g2engine.G2Engine", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class G2Engine(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def AddRecord(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/AddRecord",
            g2engine__pb2.AddRecordRequest.SerializeToString,
            g2engine__pb2.AddRecordResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def AddRecordWithInfo(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/AddRecordWithInfo",
            g2engine__pb2.AddRecordWithInfoRequest.SerializeToString,
            g2engine__pb2.AddRecordWithInfoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CloseExport(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/CloseExport",
            g2engine__pb2.CloseExportRequest.SerializeToString,
            g2engine__pb2.CloseExportResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CountRedoRecords(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/CountRedoRecords",
            g2engine__pb2.CountRedoRecordsRequest.SerializeToString,
            g2engine__pb2.CountRedoRecordsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeleteRecord(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/DeleteRecord",
            g2engine__pb2.DeleteRecordRequest.SerializeToString,
            g2engine__pb2.DeleteRecordResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeleteRecordWithInfo(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/DeleteRecordWithInfo",
            g2engine__pb2.DeleteRecordWithInfoRequest.SerializeToString,
            g2engine__pb2.DeleteRecordWithInfoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def Destroy(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/Destroy",
            g2engine__pb2.DestroyRequest.SerializeToString,
            g2engine__pb2.DestroyResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ExportConfig(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/ExportConfig",
            g2engine__pb2.ExportConfigRequest.SerializeToString,
            g2engine__pb2.ExportConfigResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ExportConfigAndConfigID(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/ExportConfigAndConfigID",
            g2engine__pb2.ExportConfigAndConfigIDRequest.SerializeToString,
            g2engine__pb2.ExportConfigAndConfigIDResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ExportCSVEntityReport(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/ExportCSVEntityReport",
            g2engine__pb2.ExportCSVEntityReportRequest.SerializeToString,
            g2engine__pb2.ExportCSVEntityReportResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ExportJSONEntityReport(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/ExportJSONEntityReport",
            g2engine__pb2.ExportJSONEntityReportRequest.SerializeToString,
            g2engine__pb2.ExportJSONEntityReportResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def FetchNext(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/FetchNext",
            g2engine__pb2.FetchNextRequest.SerializeToString,
            g2engine__pb2.FetchNextResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def FindInterestingEntitiesByEntityID(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/FindInterestingEntitiesByEntityID",
            g2engine__pb2.FindInterestingEntitiesByEntityIDRequest.SerializeToString,
            g2engine__pb2.FindInterestingEntitiesByEntityIDResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def FindInterestingEntitiesByRecordID(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/FindInterestingEntitiesByRecordID",
            g2engine__pb2.FindInterestingEntitiesByRecordIDRequest.SerializeToString,
            g2engine__pb2.FindInterestingEntitiesByRecordIDResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def FindNetworkByEntityID(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/FindNetworkByEntityID",
            g2engine__pb2.FindNetworkByEntityIDRequest.SerializeToString,
            g2engine__pb2.FindNetworkByEntityIDResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def FindNetworkByEntityID_V2(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/FindNetworkByEntityID_V2",
            g2engine__pb2.FindNetworkByEntityID_V2Request.SerializeToString,
            g2engine__pb2.FindNetworkByEntityID_V2Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def FindNetworkByRecordID(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/FindNetworkByRecordID",
            g2engine__pb2.FindNetworkByRecordIDRequest.SerializeToString,
            g2engine__pb2.FindNetworkByRecordIDResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def FindNetworkByRecordID_V2(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/FindNetworkByRecordID_V2",
            g2engine__pb2.FindNetworkByRecordID_V2Request.SerializeToString,
            g2engine__pb2.FindNetworkByRecordID_V2Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def FindPathByEntityID(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/FindPathByEntityID",
            g2engine__pb2.FindPathByEntityIDRequest.SerializeToString,
            g2engine__pb2.FindPathByEntityIDResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def FindPathByEntityID_V2(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/FindPathByEntityID_V2",
            g2engine__pb2.FindPathByEntityID_V2Request.SerializeToString,
            g2engine__pb2.FindPathByEntityID_V2Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def FindPathByRecordID(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/FindPathByRecordID",
            g2engine__pb2.FindPathByRecordIDRequest.SerializeToString,
            g2engine__pb2.FindPathByRecordIDResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def FindPathByRecordID_V2(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/FindPathByRecordID_V2",
            g2engine__pb2.FindPathByRecordID_V2Request.SerializeToString,
            g2engine__pb2.FindPathByRecordID_V2Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def FindPathExcludingByEntityID(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/FindPathExcludingByEntityID",
            g2engine__pb2.FindPathExcludingByEntityIDRequest.SerializeToString,
            g2engine__pb2.FindPathExcludingByEntityIDResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def FindPathExcludingByEntityID_V2(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/FindPathExcludingByEntityID_V2",
            g2engine__pb2.FindPathExcludingByEntityID_V2Request.SerializeToString,
            g2engine__pb2.FindPathExcludingByEntityID_V2Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def FindPathExcludingByRecordID(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/FindPathExcludingByRecordID",
            g2engine__pb2.FindPathExcludingByRecordIDRequest.SerializeToString,
            g2engine__pb2.FindPathExcludingByRecordIDResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def FindPathExcludingByRecordID_V2(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/FindPathExcludingByRecordID_V2",
            g2engine__pb2.FindPathExcludingByRecordID_V2Request.SerializeToString,
            g2engine__pb2.FindPathExcludingByRecordID_V2Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def FindPathIncludingSourceByEntityID(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/FindPathIncludingSourceByEntityID",
            g2engine__pb2.FindPathIncludingSourceByEntityIDRequest.SerializeToString,
            g2engine__pb2.FindPathIncludingSourceByEntityIDResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def FindPathIncludingSourceByEntityID_V2(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/FindPathIncludingSourceByEntityID_V2",
            g2engine__pb2.FindPathIncludingSourceByEntityID_V2Request.SerializeToString,
            g2engine__pb2.FindPathIncludingSourceByEntityID_V2Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def FindPathIncludingSourceByRecordID(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/FindPathIncludingSourceByRecordID",
            g2engine__pb2.FindPathIncludingSourceByRecordIDRequest.SerializeToString,
            g2engine__pb2.FindPathIncludingSourceByRecordIDResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def FindPathIncludingSourceByRecordID_V2(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/FindPathIncludingSourceByRecordID_V2",
            g2engine__pb2.FindPathIncludingSourceByRecordID_V2Request.SerializeToString,
            g2engine__pb2.FindPathIncludingSourceByRecordID_V2Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetActiveConfigID(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/GetActiveConfigID",
            g2engine__pb2.GetActiveConfigIDRequest.SerializeToString,
            g2engine__pb2.GetActiveConfigIDResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetEntityByEntityID(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/GetEntityByEntityID",
            g2engine__pb2.GetEntityByEntityIDRequest.SerializeToString,
            g2engine__pb2.GetEntityByEntityIDResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetEntityByEntityID_V2(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/GetEntityByEntityID_V2",
            g2engine__pb2.GetEntityByEntityID_V2Request.SerializeToString,
            g2engine__pb2.GetEntityByEntityID_V2Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetEntityByRecordID(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/GetEntityByRecordID",
            g2engine__pb2.GetEntityByRecordIDRequest.SerializeToString,
            g2engine__pb2.GetEntityByRecordIDResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetEntityByRecordID_V2(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/GetEntityByRecordID_V2",
            g2engine__pb2.GetEntityByRecordID_V2Request.SerializeToString,
            g2engine__pb2.GetEntityByRecordID_V2Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetRecord(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/GetRecord",
            g2engine__pb2.GetRecordRequest.SerializeToString,
            g2engine__pb2.GetRecordResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetRecord_V2(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/GetRecord_V2",
            g2engine__pb2.GetRecord_V2Request.SerializeToString,
            g2engine__pb2.GetRecord_V2Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetRedoRecord(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/GetRedoRecord",
            g2engine__pb2.GetRedoRecordRequest.SerializeToString,
            g2engine__pb2.GetRedoRecordResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetRepositoryLastModifiedTime(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/GetRepositoryLastModifiedTime",
            g2engine__pb2.GetRepositoryLastModifiedTimeRequest.SerializeToString,
            g2engine__pb2.GetRepositoryLastModifiedTimeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetVirtualEntityByRecordID(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/GetVirtualEntityByRecordID",
            g2engine__pb2.GetVirtualEntityByRecordIDRequest.SerializeToString,
            g2engine__pb2.GetVirtualEntityByRecordIDResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetVirtualEntityByRecordID_V2(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/GetVirtualEntityByRecordID_V2",
            g2engine__pb2.GetVirtualEntityByRecordID_V2Request.SerializeToString,
            g2engine__pb2.GetVirtualEntityByRecordID_V2Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def HowEntityByEntityID(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/HowEntityByEntityID",
            g2engine__pb2.HowEntityByEntityIDRequest.SerializeToString,
            g2engine__pb2.HowEntityByEntityIDResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def HowEntityByEntityID_V2(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/HowEntityByEntityID_V2",
            g2engine__pb2.HowEntityByEntityID_V2Request.SerializeToString,
            g2engine__pb2.HowEntityByEntityID_V2Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def Init(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/Init",
            g2engine__pb2.InitRequest.SerializeToString,
            g2engine__pb2.InitResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def InitWithConfigID(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/InitWithConfigID",
            g2engine__pb2.InitWithConfigIDRequest.SerializeToString,
            g2engine__pb2.InitWithConfigIDResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def PrimeEngine(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/PrimeEngine",
            g2engine__pb2.PrimeEngineRequest.SerializeToString,
            g2engine__pb2.PrimeEngineResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def Process(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/Process",
            g2engine__pb2.ProcessRequest.SerializeToString,
            g2engine__pb2.ProcessResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ProcessWithInfo(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/ProcessWithInfo",
            g2engine__pb2.ProcessWithInfoRequest.SerializeToString,
            g2engine__pb2.ProcessWithInfoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def PurgeRepository(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/PurgeRepository",
            g2engine__pb2.PurgeRepositoryRequest.SerializeToString,
            g2engine__pb2.PurgeRepositoryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ReevaluateEntity(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/ReevaluateEntity",
            g2engine__pb2.ReevaluateEntityRequest.SerializeToString,
            g2engine__pb2.ReevaluateEntityResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ReevaluateEntityWithInfo(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/ReevaluateEntityWithInfo",
            g2engine__pb2.ReevaluateEntityWithInfoRequest.SerializeToString,
            g2engine__pb2.ReevaluateEntityWithInfoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ReevaluateRecord(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/ReevaluateRecord",
            g2engine__pb2.ReevaluateRecordRequest.SerializeToString,
            g2engine__pb2.ReevaluateRecordResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ReevaluateRecordWithInfo(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/ReevaluateRecordWithInfo",
            g2engine__pb2.ReevaluateRecordWithInfoRequest.SerializeToString,
            g2engine__pb2.ReevaluateRecordWithInfoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def Reinit(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/Reinit",
            g2engine__pb2.ReinitRequest.SerializeToString,
            g2engine__pb2.ReinitResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ReplaceRecord(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/ReplaceRecord",
            g2engine__pb2.ReplaceRecordRequest.SerializeToString,
            g2engine__pb2.ReplaceRecordResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ReplaceRecordWithInfo(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/ReplaceRecordWithInfo",
            g2engine__pb2.ReplaceRecordWithInfoRequest.SerializeToString,
            g2engine__pb2.ReplaceRecordWithInfoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def SearchByAttributes(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/SearchByAttributes",
            g2engine__pb2.SearchByAttributesRequest.SerializeToString,
            g2engine__pb2.SearchByAttributesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def SearchByAttributes_V2(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/SearchByAttributes_V2",
            g2engine__pb2.SearchByAttributes_V2Request.SerializeToString,
            g2engine__pb2.SearchByAttributes_V2Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def Stats(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/Stats",
            g2engine__pb2.StatsRequest.SerializeToString,
            g2engine__pb2.StatsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def StreamExportCSVEntityReport(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_stream(
            request,
            target,
            "/g2engine.G2Engine/StreamExportCSVEntityReport",
            g2engine__pb2.StreamExportCSVEntityReportRequest.SerializeToString,
            g2engine__pb2.StreamExportCSVEntityReportResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def StreamExportJSONEntityReport(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_stream(
            request,
            target,
            "/g2engine.G2Engine/StreamExportJSONEntityReport",
            g2engine__pb2.StreamExportJSONEntityReportRequest.SerializeToString,
            g2engine__pb2.StreamExportJSONEntityReportResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def WhyEntities(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/WhyEntities",
            g2engine__pb2.WhyEntitiesRequest.SerializeToString,
            g2engine__pb2.WhyEntitiesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def WhyEntities_V2(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/WhyEntities_V2",
            g2engine__pb2.WhyEntities_V2Request.SerializeToString,
            g2engine__pb2.WhyEntities_V2Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def WhyEntityByEntityID(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/WhyEntityByEntityID",
            g2engine__pb2.WhyEntityByEntityIDRequest.SerializeToString,
            g2engine__pb2.WhyEntityByEntityIDResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def WhyEntityByEntityID_V2(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/WhyEntityByEntityID_V2",
            g2engine__pb2.WhyEntityByEntityID_V2Request.SerializeToString,
            g2engine__pb2.WhyEntityByEntityID_V2Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def WhyEntityByRecordID(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/WhyEntityByRecordID",
            g2engine__pb2.WhyEntityByRecordIDRequest.SerializeToString,
            g2engine__pb2.WhyEntityByRecordIDResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def WhyEntityByRecordID_V2(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/WhyEntityByRecordID_V2",
            g2engine__pb2.WhyEntityByRecordID_V2Request.SerializeToString,
            g2engine__pb2.WhyEntityByRecordID_V2Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def WhyRecords(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/WhyRecords",
            g2engine__pb2.WhyRecordsRequest.SerializeToString,
            g2engine__pb2.WhyRecordsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def WhyRecords_V2(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/g2engine.G2Engine/WhyRecords_V2",
            g2engine__pb2.WhyRecords_V2Request.SerializeToString,
            g2engine__pb2.WhyRecords_V2Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



#! /usr/bin/env python3

"""
TODO: g2configmgr_grpc.py
"""

# pylint: disable=E1101

from types import TracebackType
from typing import Any, Dict, Type, Union

import grpc
from senzing_abstract import G2ConfigMgrAbstract

# from .g2exception import translate_exception
from .g2helpers import as_str, new_exception
from .pb2_grpc import g2configmgr_pb2, g2configmgr_pb2_grpc

# Metadata

__all__ = ["G2ConfigMgrGrpc"]
__version__ = "0.0.1"  # See https://www.python.org/dev/peps/pep-0396/
__date__ = "2023-11-27"
__updated__ = "2023-12-16"

SENZING_PRODUCT_ID = "5051"  # See https://github.com/Senzing/knowledge-base/blob/main/lists/senzing-component-ids.md

# -----------------------------------------------------------------------------
# G2ConfigMgrGrpc class
# -----------------------------------------------------------------------------


class G2ConfigMgrGrpc(G2ConfigMgrAbstract):  # type: ignore
    """
    G2 config-manager module access library over gRPC.
    """

    # -------------------------------------------------------------------------
    # Python dunder/magic methods
    # -------------------------------------------------------------------------

    def __init__(
        self,
        grpc_channel: grpc.Channel,
    ) -> None:
        """
        Constructor

        For return value of -> None, see https://peps.python.org/pep-0484/#the-meaning-of-annotations
        """

        self.channel = grpc_channel
        self.stub = g2configmgr_pb2_grpc.G2ConfigMgrStub(self.channel)

    def __enter__(
        self,
    ) -> (
        Any
    ):  # TODO: Replace "Any" with "Self" once python 3.11 is lowest supported python version.
        """Context Manager method."""
        return self

    def __exit__(
        self,
        exc_type: Union[Type[BaseException], None],
        exc_val: Union[BaseException, None],
        exc_tb: Union[TracebackType, None],
    ) -> None:
        """Context Manager method."""

    # -------------------------------------------------------------------------
    # G2ConfigMgr methods
    # -------------------------------------------------------------------------

    def add_config(
        self,
        config_str: Union[str, Dict[Any, Any]],
        config_comments: str,
        *args: Any,
        **kwargs: Any,
    ) -> int:
        try:
            request = g2configmgr_pb2.AddConfigRequest(  # type: ignore[unused-ignore]
                configStr=as_str(config_str), configComments=as_str(config_comments)
            )
            response = self.stub.AddConfig(request)
            return int(response.result)
        except Exception as err:
            raise new_exception(err) from err

    def destroy(self, *args: Any, **kwargs: Any) -> None:
        """Null function"""

    def get_config(self, config_id: int, *args: Any, **kwargs: Any) -> str:
        try:
            request = g2configmgr_pb2.GetConfigRequest(configID=config_id)  # type: ignore[unused-ignore]
            response = self.stub.GetConfig(request)
            return str(response.result)
        except Exception as err:
            raise new_exception(err) from err

    def get_config_list(self, *args: Any, **kwargs: Any) -> str:
        try:
            request = g2configmgr_pb2.GetConfigListRequest()  # type: ignore[unused-ignore]
            response = self.stub.GetConfigList(request)
            return str(response.result)
        except Exception as err:
            raise new_exception(err) from err

    def get_default_config_id(self, *args: Any, **kwargs: Any) -> int:
        try:
            request = g2configmgr_pb2.GetDefaultConfigIDRequest()  # type: ignore[unused-ignore]
            response = self.stub.GetDefaultConfigID(request)
            return int(response.configID)
        except Exception as err:
            raise new_exception(err) from err

    def init(
        self,
        module_name: str,
        ini_params: Union[str, Dict[Any, Any]],
        verbose_logging: int = 0,
        **kwargs: Any,
    ) -> None:
        """Null function"""

    def replace_default_config_id(
        self, old_config_id: int, new_config_id: int, *args: Any, **kwargs: Any
    ) -> None:
        try:
            request = g2configmgr_pb2.ReplaceDefaultConfigIDRequest(  # type: ignore[unused-ignore]
                oldConfigID=old_config_id,
                newConfigID=new_config_id,
            )
            self.stub.ReplaceDefaultConfigID(request)
        except Exception as err:
            raise new_exception(err) from err

    def set_default_config_id(self, config_id: int, *args: Any, **kwargs: Any) -> None:
        try:
            request = g2configmgr_pb2.SetDefaultConfigIDRequest(  # type: ignore[unused-ignore]
                configID=config_id,
            )
            self.stub.SetDefaultConfigID(request)
        except Exception as err:
            raise new_exception(err) from err



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: g2configmgr.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x11g2configmgr.proto\x12\x0bg2configmgr"=\n\x10\x41\x64\x64\x43onfigRequest\x12\x11\n\tconfigStr\x18\x01 \x01(\t\x12\x16\n\x0e\x63onfigComments\x18\x02 \x01(\t"#\n\x11\x41\x64\x64\x43onfigResponse\x12\x0e\n\x06result\x18\x01 \x01(\x03"\x10\n\x0e\x44\x65stroyRequest"\x11\n\x0f\x44\x65stroyResponse"$\n\x10GetConfigRequest\x12\x10\n\x08\x63onfigID\x18\x01 \x01(\x03"#\n\x11GetConfigResponse\x12\x0e\n\x06result\x18\x01 \x01(\t"\x16\n\x14GetConfigListRequest"\'\n\x15GetConfigListResponse\x12\x0e\n\x06result\x18\x01 \x01(\t"\x1b\n\x19GetDefaultConfigIDRequest".\n\x1aGetDefaultConfigIDResponse\x12\x10\n\x08\x63onfigID\x18\x01 \x01(\x03"L\n\x0bInitRequest\x12\x12\n\nmoduleName\x18\x01 \x01(\t\x12\x11\n\tiniParams\x18\x02 \x01(\t\x12\x16\n\x0everboseLogging\x18\x03 \x01(\x03"\x0e\n\x0cInitResponse"I\n\x1dReplaceDefaultConfigIDRequest\x12\x13\n\x0boldConfigID\x18\x01 \x01(\x03\x12\x13\n\x0bnewConfigID\x18\x02 \x01(\x03" \n\x1eReplaceDefaultConfigIDResponse"-\n\x19SetDefaultConfigIDRequest\x12\x10\n\x08\x63onfigID\x18\x01 \x01(\x03"\x1c\n\x1aSetDefaultConfigIDResponse2\xd1\x05\n\x0bG2ConfigMgr\x12L\n\tAddConfig\x12\x1d.g2configmgr.AddConfigRequest\x1a\x1e.g2configmgr.AddConfigResponse"\x00\x12\x46\n\x07\x44\x65stroy\x12\x1b.g2configmgr.DestroyRequest\x1a\x1c.g2configmgr.DestroyResponse"\x00\x12L\n\tGetConfig\x12\x1d.g2configmgr.GetConfigRequest\x1a\x1e.g2configmgr.GetConfigResponse"\x00\x12X\n\rGetConfigList\x12!.g2configmgr.GetConfigListRequest\x1a".g2configmgr.GetConfigListResponse"\x00\x12g\n\x12GetDefaultConfigID\x12&.g2configmgr.GetDefaultConfigIDRequest\x1a\'.g2configmgr.GetDefaultConfigIDResponse"\x00\x12=\n\x04Init\x12\x18.g2configmgr.InitRequest\x1a\x19.g2configmgr.InitResponse"\x00\x12s\n\x16ReplaceDefaultConfigID\x12*.g2configmgr.ReplaceDefaultConfigIDRequest\x1a+.g2configmgr.ReplaceDefaultConfigIDResponse"\x00\x12g\n\x12SetDefaultConfigID\x12&.g2configmgr.SetDefaultConfigIDRequest\x1a\'.g2configmgr.SetDefaultConfigIDResponse"\x00\x42k\n&com.senzing.g2.engine.grpc.G2ConfigMgrB\x10G2ConfigMgrProtoP\x01Z-github.com/senzing/g2-sdk-go-grpc/g2configmgrb\x06proto3'
)

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "g2configmgr_pb2", globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b"\n&com.senzing.g2.engine.grpc.G2ConfigMgrB\020G2ConfigMgrProtoP\001Z-github.com/senzing/g2-sdk-go-grpc/g2configmgr"
    _ADDCONFIGREQUEST._serialized_start = 34
    _ADDCONFIGREQUEST._serialized_end = 95
    _ADDCONFIGRESPONSE._serialized_start = 97
    _ADDCONFIGRESPONSE._serialized_end = 132
    _DESTROYREQUEST._serialized_start = 134
    _DESTROYREQUEST._serialized_end = 150
    _DESTROYRESPONSE._serialized_start = 152
    _DESTROYRESPONSE._serialized_end = 169
    _GETCONFIGREQUEST._serialized_start = 171
    _GETCONFIGREQUEST._serialized_end = 207
    _GETCONFIGRESPONSE._serialized_start = 209
    _GETCONFIGRESPONSE._serialized_end = 244
    _GETCONFIGLISTREQUEST._serialized_start = 246
    _GETCONFIGLISTREQUEST._serialized_end = 268
    _GETCONFIGLISTRESPONSE._serialized_start = 270
    _GETCONFIGLISTRESPONSE._serialized_end = 309
    _GETDEFAULTCONFIGIDREQUEST._serialized_start = 311
    _GETDEFAULTCONFIGIDREQUEST._serialized_end = 338
    _GETDEFAULTCONFIGIDRESPONSE._serialized_start = 340
    _GETDEFAULTCONFIGIDRESPONSE._serialized_end = 386
    _INITREQUEST._serialized_start = 388
    _INITREQUEST._serialized_end = 464
    _INITRESPONSE._serialized_start = 466
    _INITRESPONSE._serialized_end = 480
    _REPLACEDEFAULTCONFIGIDREQUEST._serialized_start = 482
    _REPLACEDEFAULTCONFIGIDREQUEST._serialized_end = 555
    _REPLACEDEFAULTCONFIGIDRESPONSE._serialized_start = 557
    _REPLACEDEFAULTCONFIGIDRESPONSE._serialized_end = 589
    _SETDEFAULTCONFIGIDREQUEST._serialized_start = 591
    _SETDEFAULTCONFIGIDREQUEST._serialized_end = 636
    _SETDEFAULTCONFIGIDRESPONSE._serialized_start = 638
    _SETDEFAULTCONFIGIDRESPONSE._serialized_end = 666
    _G2CONFIGMGR._serialized_start = 669
    _G2CONFIGMGR._serialized_end = 1390
# @@protoc_insertion_point(module_scope)
